@@ -103,9 +103,13 @@ class ChannelTestCase(ChannelPluginTestCase):
             self.irc.feedMsg(ircmsgs.deop(self.channel, self.nick))
 
     def testWontDeItself(self):
-        for s in 'deop dehalfop devoice'.split():
+        for s in 'deop dehalfop'.split():
             self.irc.feedMsg(ircmsgs.op(self.channel, self.nick))
             self.assertError('%s %s' % (s, self.nick))
+            
+    def testCanDevoiceSelf(self):
+        self.irc.feedMsg(ircmsgs.op(self.channel, self.nick))
+        self.assertNotError('devoice %s' % self.nick)
 
     def testOp(self):
         self.assertError('op')
@@ -251,6 +255,27 @@ class ChannelTestCase(ChannelPluginTestCase):
     def testNicks(self):
         self.assertResponse('channel nicks', 'bar, foo, and test')
         self.assertResponse('channel nicks --count', '3')
-        
+
+    def testPart(self):
+        def getAfterJoinMessages():
+            m = self.irc.takeMsg()
+            self.assertEqual(m.command, 'MODE')
+            m = self.irc.takeMsg()
+            self.assertEqual(m.command, 'MODE')
+            m = self.irc.takeMsg()
+            self.assertEqual(m.command, 'WHO')
+        self.assertError('part #foo')
+        self.assertRegexp('part #foo', 'not in')
+        self.irc.feedMsg(ircmsgs.join('#foo', prefix=self.prefix))
+        getAfterJoinMessages()
+        m = self.getMsg('part #foo')
+        self.assertEqual(m.command, 'PART')
+        self.irc.feedMsg(ircmsgs.join('#foo', prefix=self.prefix))
+        getAfterJoinMessages()
+        m = self.getMsg('part #foo reason')
+        self.assertEqual(m.command, 'PART')
+        self.assertEqual(m.args[0], '#foo')
+        self.assertEqual(m.args[1], 'reason')
+
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
 
